﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1:
    python hide:
        
        #_button_menu()

        ## Should we enable the use of developer tools? This should be
        ## set to False before the game is released, so the user can't
        ## cheat using developer tools.

        config.developer = False
        
        ## These control the width and height of the screen.

        config.screen_width = 800
        config.screen_height = 600

        ## This controls the title of the window, when Ren'Py is
        ## running in a window.

        config.window_title = u"Tying Threads"

        ## We then want to call a theme function. themes.roundrect is
        ## a theme that features the use of rounded rectangles. It's
        ## the only theme we currently support.
        ##
        ## The theme function takes a number of parameters that can
        ## customize the color scheme.
#        theme.roundrect(

            ## The color of an idle widget face.
#            widget = "#003c78",

            ## The color of a focused widget face.
#            widget_hover = "#0050a0",

            ## The color of the text in a widget.
#            widget_text = "#c8ffff",

            ## The color of the text in a selected widget. (For
            ## example, the current value of a preference.)
#            widget_selected = "#ffffc8",

            ## The color of a disabled widget face. 
#            disabled = "#404040",

            ## The color of disabled widget text.
#            disabled_text = "#c8c8c8",

            ## The color of informational labels.
#            label = "#ffffff",

            ## The color of a frame containing widgets.
#            frame = "#6496c8",

            ## If this is True, in-game menus are placed in the center
            ## the screen. If False, they are placed inside a window
            ## at the bottom of the screen.
#            button_menu = False,

            ## The background of the main menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
#            mm_root = "#dcebff",

            ## The background of the game menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
#            gm_root = "#dcebff",

            ## And we're done with the theme. The theme will customize
            ## various styles, so if we want to change them, we should
            ## do so below.            
#            )


        #########################################
        ## These settings let you customize the window containing the
        ## dialogue and narration, by replacing it with an image.

        ## The background of the window. In a Frame, the two numbers
        ## are the size of the left/right and top/bottom borders,
        ## respectively.

        style.window.background = Frame("frame.png", 25, 25)
        # style.window.background = Frame("frame.png", 12, 12)
        
        ## Margin is space surrounding the window, where the background
        ## is not drawn.

        # style.window.left_margin = 6
        # style.window.right_margin = 6
        # style.window.top_margin = 6
        # style.window.bottom_margin = 6
        
        ## Padding is space inside the window, where the background is
        ## drawn.

        # style.window.left_padding = 6
        # style.window.right_padding = 6
        # style.window.top_padding = 6
        # style.window.bottom_padding = 6

        ## This is the minimum height of the window, including the margins
        ## and padding.

        # style.window.yminimum = 250


        #########################################
        ## This lets you change the placement of the main menu.
        
        ## The way placement works is that we find an anchor point
        ## inside a displayable, and a position (pos) point on the
        ## screen. We then place the displayable so the two points are
        ## at the same place.

        ## An anchor/pos can be given as an integer or a floating point
        ## number. If an integer, the number is interpreted as a number
        ## of pixels from the upper-left corner. If a floating point,
        ## the number is interpreted as a fraction of the size of the
        ## displayable or screen.

        style.mm_menu_window.xpos = 0.75
        style.mm_menu_window.xanchor = 'center'
        style.mm_menu_window.ypos = 0.75
        style.mm_menu_window.yanchor = 'center'
        # style.mm_menu_frame.xpos = 0.5
        # style.mm_menu_frame.xanchor = 0.5
        # style.mm_menu_frame.ypos = 0.75
        # style.mm_menu_frame.yanchor = 0.5


        #########################################
        ## These let you customize the default font used for text in Ren'Py.

        ## The file containing the default font.

        # style.default.font = "DejaVuSans.ttf"

        ## The default size of text.

        # style.default.size = 22

        ## Note that these only change the size of some of the text. Other
        ## buttons have their own styles.


        #########################################
        ## These settings let you change some of the sounds that are used by
        ## Ren'Py.

        ## Set this to False if the game does not have any sound effects.

        library.has_sound = True

        ## Set this to False if the game does not have any music.

        library.has_music = True

        ## Sounds that are used when button and imagemaps are clicked.

        # style.button.activate_sound = "click.wav"
        # style.imagemap.activate_sound = "click.wav"

        ## Sounds that are used when entering and exiting the game menu.

        # library.enter_sound = "click.wav"
        # library.exit_sound = "click.wav"

        ## A sample sound that can be played to check the sound volume.

        # library.sample_sound = "click.wav"

        ## Music that is played while the user is at the main menu.

        config.main_menu_music = "Evening Fall Piano Lo.ogg"

        
        #########################################
        ## Miscellaneous customizations

        ## These let you change the transitions that are used when entering
        ## and exiting the game menu.
        #style.say_dialogue.what_prefix = "\""

        library.enter_transition = dissolve
        library.exit_transition = dissolve
        
        #config.intra_transition = dissolve
        
        # Change some styles, to add images in the background of
        # the menus and windows.
        style.mm_root_window.background = Image("mmBG-sketch.png")
        style.gm_root_window.background = Image("gmBG-sketch.png")

        # Change the look of the slider.
        style.bar.left_gutter = 10
        style.bar.right_gutter = 12
        style.bar.left_bar = Frame("slider_full.png", 10, 0)
        style.bar.right_bar = Frame("slider_empty.png", 12, 0)
        style.bar.thumb = Image("slider_idle.png")
        style.bar.hover_thumb = Image("slider_hover.png")
        style.bar.thumb_shadow = Image("slider_shadow.png")
        style.bar.thumb_offset = -10

        # Change some styles involving the margins and padding of the
        # default window. (We need this, as we use a frame image that
        # includes a drop-shadow.)
        style.window.xmargin = 0
        style.window.ymargin = 0
        style.window.xpadding = 20
        style.window.top_padding = 5
        style.window.bottom_padding = 15

        # Interface sounds, just for the heck of it.
        # style.button.activate_sound = 'click.wav'
        # style.imagemap.activate_sound = 'click.wav'
        # library.enter_sound = 'click.wav'
        # library.exit_sound = 'click.wav'
        library.sample_sound = "18005551212.ogg"

        # Select the transitions that are used when entering and exiting
        # the game menu.
        library.enter_transition = dissolve
        library.exit_transition = dissolve
        
        style.say_label.bold = False
        style.say_label.font = "subfont"
        
        #style.menu_window.yminimum = 0.6
        style.menu_window.background = None
        
        style.default.size = 22
        style.default.color = "#ffffff"
        style.default.black_color = "#082AC4"
        style.default.bold = False
        style.default.font = "subfont"
        
        style.menu_button_text.size = 22
        style.prefs_button_text.size = 22
        style.file_picker_text.size = 22
        
        idleColor = "#061E89"
        selectedColor = "#0088A1"
        hoverColor = "#859BFF"
        centerColor = "#ffffff"
        darkColor = "#808080"
        blackColor = "#000000"

    
        style.button_text.color = centerColor
        style.button_text.black_color = blackColor
        style.button_text.hover_black_color = darkColor
        style.button_text.selected_black_color = darkColor
        
        
        style.menu_caption.size = 22
        style.menu_choice.size = 22
        style.menu_choice.color = centerColor
        style.menu_choice.black_color = idleColor
        style.menu_choice.hover_black_color = hoverColor
        
        style.file_picker_text.color = centerColor
        style.file_picker_text.black_color = blackColor
        style.file_picker_text.hover_black_color = darkColor
        style.file_picker_text.selected_black_color = darkColor
        
        style.prefs_label.color = centerColor
        style.prefs_label.black_color = "#000000"

        style.yesno_label.color = centerColor
        style.yesno_label.black_color = "#000000"

        style.file_picker_entry.background = None
        style.file_picker_entry.hover_background = None
        
        style.menu_caption.font = "subfont"
        style.menu_caption.ypadding = 20
        
        style.menu_choice.font = "subfont"
        #style.menu_choice.black_color = "#ff0000"
        style.menu_caption.background = None
        
        #style.menu.box_spacing = 2
        style.menu_window.xpos = 0.5
        style.menu_window.xanchor = 0.5
        style.menu_window.ypos = 0.5
        style.menu_window.yanchor = 0.5
        style.menu_choice.clear()
        style.menu_choice.take(style.button_text)
        style.menu_choice_button.clear()
        style.menu_choice_button.take(style.button)
        style.menu_choice_chosen.clear()
        style.menu_choice_chosen_button.clear()
        style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
        style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
        



        style.menu_caption.size = 22
        style.menu_choice.size = 22

        style.menu.box_spacing = 2
        
        style.menu.xalign = 0.5
        style.menu.text_align = 0.5
        # Set the color of idle chosen menu choices.
        #style.menu_choice_chosen.idle_color = (255,255,255,255)
        #style.menu_choice.idle_color = (255,255,255,255)
        #style.menu_choice.hover_color = (255,255,255,255)
        
        #style.menu_choice_chosen.idle_black_color = (150, 150, 150, 255)
        #style.menu_choice.idle_black_color = (150,150,150,255)
        #style.menu_choice.hover_black_color = (0,0,0,255)
    
        #style.say_dialogue.color = (255,255,255,255)
    
        # set the colors of game menu buttons
        #style.button_text.size = 24
        #style.button_text.color = (0,0,0,255)
        #style.button_text.hover_color = (100,100,100,255)
        # style.button_text.activate_color = (0,0,255,255)
        #style.selected_button_text.color = (130,0,130,255)
        # style.selected_button_text.hover_color = (0,0,200,255)
        # style.selected_button_text.activate_color = (0,0,200,255)

        style.button_text.drop_shadow = None
